@@ -197,9 +197,8 @@ static void mafw_gst_renderer_class_init(MafwGstRendererClass *klass)
 	GObjectClass *gclass = NULL;
 	MafwRendererClass *renderer_class = NULL;
 	const gchar *preloaded_plugins[] = {"playback", "uridecodebin",
-		"coreelements", "typefindfunctions", "omx", "selector",
-		"autodetect", "pulseaudio", "audioconvert", "audioresample",
-		"xvimagesink", "ffmpegcolorspace", "videoscale", NULL};
+				"coreelements", "typefindfunctions", "dsp",
+				"pulseaudio", "xvimagesink", NULL};
 	gint i = 0;
 	GObject *plugin;
 
@@ -273,7 +272,9 @@ static void mafw_gst_renderer_init(MafwGstRenderer *self)
 	g_return_if_fail(renderer != NULL);
 
 	mafw_extension_add_property(MAFW_EXTENSION(self), "volume", G_TYPE_UINT);
+#ifdef MAFW_GST_RENDERER_ENABLE_MUTE
 	mafw_extension_add_property(MAFW_EXTENSION(self), "mute", G_TYPE_BOOLEAN);
+#endif
 	mafw_extension_add_property(MAFW_EXTENSION(self), "xid", G_TYPE_UINT);
 	mafw_extension_add_property(MAFW_EXTENSION(self), "error-policy", G_TYPE_UINT);
 	MAFW_EXTENSION_SUPPORTS_AUTOPAINT(self);
@@ -2172,6 +2173,11 @@ static void mafw_gst_renderer_set_property(MafwExtension *self,
 			renderer->worker,
 			g_value_get_boolean(value));
 	}
+	else if (!strcmp(key, MAFW_PROPERTY_RENDERER_COLORKEY)) {
+		mafw_gst_renderer_worker_set_colorkey(
+			renderer->worker,
+			g_value_get_int(value));
+	}
 #ifdef HAVE_GDKPIXBUF
 	else if (!strcmp(key,
 			 MAFW_PROPERTY_GST_RENDERER_CURRENT_FRAME_ON_PAUSE)) {
